fix_library_calls: Reformat from library calls

View source: R/overwrite_library.R

fix_library_callsR Documentation

Reformat from library calls

Description

Replace calls to library with namespace::functions

Usage

fix_library_calls(
  file,
  outfile = NULL,
  consider_loaded_namespaces = FALSE,
  remove_lib_calls = FALSE
)

Arguments

file

The file to fix the calls in.

outfile

The file to write the output by default - defaults to **NULL** and does not write to a file.

consider_loaded_namespaces

Look for potential matches to function in loaded namespaces.

remove_lib_calls

Remove the calls to library/require after replacements are done.

Value

The fixed code (as a string).


JSzitas/autodep documentation built on April 4, 2022, 1:48 a.m.