View source: R/overwrite_library.R
| fix_library_calls | R Documentation |
Replace calls to library with namespace::functions
fix_library_calls( file, outfile = NULL, consider_loaded_namespaces = FALSE, remove_lib_calls = FALSE )
file |
The file to fix the calls in. |
outfile |
The file to write the output by default - defaults to **NULL** and does not write to a file. |
consider_loaded_namespaces |
Look for potential matches to function in loaded namespaces. |
remove_lib_calls |
Remove the calls to library/require after replacements are done. |
The fixed code (as a string).
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.